#!/usr/local/bin/perl -w

=head1 NAME

01revmapdb.t - testing of VCP::RevMapDB::sdbm

=cut

use strict;

use Carp;
use Test;
use File::Path;
use VCP::Debug qw( enable_debug );
use VCP::RevMapDB;

enable_debug( split /,/, $ENV{VCPDEBUG} ) if defined $ENV{VCPDEBUG} ;

my $t = -d 't' ? 't/' : '' ;
my $db_loc = "${t}01revmapdb";

rmtree [$db_loc] or die "$! unlinking $db_loc" if -e $db_loc;

my $db;
my $v;

my @tests = (
sub {
   $db = VCP::RevMapDB->new( StoreLoc => $db_loc );
   ok $db;
},

sub {
   ok ! -e $db_loc;
},

sub {
   $db->mkdir_store_loc;
   ok -d $db_loc;
},

sub {
   $db->rmdir_store_loc;
   ok ! -e $db_loc;
},

sub {
   $v = $db->pack_values( "a", "b" );
   ok $v, "a;b";
},

sub {
   ok join( "|", $db->unpack_values( $v ) ), "a|b";
},

sub {
   $v = $db->pack_values( "a;b", "b" );
   ok $v, "a%,b;b";
},

sub {
   ok join( "|", $db->unpack_values( $v ) ), "a;b|b";
},

sub {
   rmtree [$db_loc] or warn "$! unlinking $db_loc" if -e $db_loc;
   ok 1;
},

) ;

plan tests => scalar( @tests ) ;

$_->() for @tests ;
